@@ -18,6 +18,9 @@ export const SETTING_KEYS = {
   FEATURES_ENABLE_VITAL_EDIT: 'features.enableVitalEdit',
   VITAL_EDIT_REASONS: 'vitalEditReasons',
   FILE_CHOOSER_MB_SIZE_LIMIT: 'fileChooserMbSizeLimit',
+  SECURITY_LOGIN_ATTEMPTS: 'security.loginAttempts',
+  SECURITY_MOBILE_ALLOW_UNENCRYPTED_STORAGE: 'security.mobile.allowUnencryptedStorage',
+  SECURITY_MOBILE_ALLOW_UNPROTECTED: 'security.mobile.allowUnprotected',
 };
 
 export const SETTINGS_SCOPES = {
